![Basic tests](https://github.com/DIRACGrid/diracx/actions/workflows/main.yml/badge.svg?branch=main)
![Basic tests](https://github.com/DIRACGrid/diracx/actions/workflows/containerised.yml/badge.svg?branch=main)

# DiracX Prototype

This repository contains the proof-of-concept code for DiracX.
It is still extremely incomplete and lacking in documentation.
Feel free to look around however try not to draw any conclusions as the code is still rapidly evolving.
